function e=humde(mr,t)
% humde  - Gives the enthalpy of air for given mass rat. & t
% function e=humde(mr,t)
% Argument List:
% Argument   Gives
%   mr     the mass ratio of water to dry air.
%   t      the temperature in units of Tdeg.
% e is the enthalpy in kJ per kg of dry air
% relative to dry air and liquid water at 0C.
ns=1000*[[.79 .21]/28.85264,mr/18.016];
hs=HinkJ(t,'v');
hr=[-0.7272 -0.7343 -287.4903];
e=sum(ns.*(hs-hr));
